@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2020 Mellanox Technologies, Ltd. All rights reserved.
+ * Copyright (c) 2001-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -348,7 +348,6 @@ inline void create_multicast_mac_from_ip(unsigned char* mc_mac, in_addr_t ip)
 
 static inline void create_mgid_from_ipv4_mc_ip(uint8_t *mgid, uint16_t pkey, uint32_t ip)
 {
-
 //  +--------+----+----+-----------------+---------+-------------------+
 //  |   8    |  4 |  4 |     16 bits     | 16 bits |      80 bits      |
 //  +--------+----+----+-----------------+---------+-------------------+
@@ -367,6 +366,7 @@ static inline void create_mgid_from_ipv4_mc_ip(uint8_t *mgid, uint16_t pkey, uin
 
 	//P_Key
 	mgid[4] = (((unsigned char *)(&pkey))[0]);
+	/* cppcheck-suppress objectIndex */
 	mgid[5] = (((unsigned char *)(&pkey))[1]);
 
 	//group ID - relevant only for ipv4
@@ -419,7 +419,7 @@ class loops_timer {
                         //update timer
                         gettime(&m_current);
                         ts_sub(&m_current, &m_start, &m_elapsed);
-                        vlog_printf(VLOG_FUNC_ALL, "update loops_timer (elapsed time=%d sec %d usec \n", ts_to_sec(&m_elapsed), ts_to_usec(&m_elapsed));
+                        vlog_printf(VLOG_FUNC_ALL, "update loops_timer (elapsed time=%ld sec %ld usec\n", ts_to_sec(&m_elapsed), ts_to_usec(&m_elapsed));
 
 
 
